@@ -1,19 +1,22 @@
 package SOAP::XML::Client;
+{
+  $SOAP::XML::Client::VERSION = '2.26';
+}
 
 use strict;
 use Carp;
-use XML::LibXML;
-use SOAP::Lite;
-use SOAP::Data::Builder;
+use XML::LibXML 0.6;
+use SOAP::Lite 0.67;
+use SOAP::Data::Builder 0.8;
 use File::Slurp;
-use Encode qw( encode decode );
+use Encode qw( decode );
 
-use vars qw($VERSION $DEBUG);
+use vars qw($DEBUG);
 
 use base qw(Class::Accessor::Fast);
 
 my @methods = qw(results results_xml uri xmlns proxy soapversion timeout error
-    strip_default_xmlns encoding header);
+    strip_default_xmlns encoding header status);
 
 # wsdk
 
@@ -21,8 +24,6 @@ __PACKAGE__->mk_accessors(@methods);
 
 $DEBUG = 0;
 
-$VERSION = 2.2;
-
 # Get an XML Parser
 my $parser = XML::LibXML->new();
 $parser->validation(0);
@@ -30,7 +31,7 @@ $parser->expand_entities(0);
 
 # which methods should be set on object constructor
 my @config_methods
-    = qw(uri xmlns proxy soapversion strip_default_xmlns encoding);
+    = qw(uri xmlns proxy soapversion strip_default_xmlns encoding timeout);
 
 sub new {
     my ( $proto, $conf ) = @_;
@@ -55,7 +56,11 @@ sub new {
         *SOAP::Serializer::as_base64Binary = sub {
             my $self = shift;
             my ( $value, $name, $type, $attr ) = @_;
-            return [ $name, { 'xsi:type' => 'xsd:string', %$attr }, $value ];
+            return [
+                $name,
+                { 'xsi:type' => 'xsd:string', %$attr },
+                SOAP::Utils::encode_data($value)
+            ];
         };
     }
 
@@ -168,14 +173,16 @@ sub fetch {
 #print Dumper($self->{sdb}->elems());
 
     # execute the call in the relevant style done by the child object
-    my $res = $self->_call( $conf->{method} );
+    my ( $res, $transport ) = $self->_call( $conf->{method} );
+
+    $self->status( $transport->status );
 
 # TODO: actually need to specify encoding expected in return (or parse from response?)
     $res = decode( $self->{encoding}, $res );
 
     carp "After run _call()" if $DEBUG;
 
-    if ( !defined $res or $res =~ /^\d/ ) {
+    if ( !defined $res or $res =~ /^\d/ or !$transport->is_success ) {
 
         # Got a web error - if it was XML it wouldn't start with a digit!
         $self->error($res);
@@ -192,7 +199,7 @@ sub fetch {
         if ($@) {
 
             # Not valid xml
-            $self->error('Unable to parse returned data as XML');
+            $self->error( 'Unable to parse returned data as XML: ' . $@ );
             return undef;
         } else {
 
@@ -259,8 +266,7 @@ sub _process_node {
         if ( $att->name() eq '_value_type' ) {
             $type = $att->value();
         } else {
-            $attribs{ $att->name() }
-                = encode( $self->{encoding}, $att->value() );
+            $attribs{ $att->name() } = $att->value();
         }
     }
 
@@ -280,7 +286,7 @@ sub _process_node {
             name       => $conf->{node}->nodeName,
             attributes => \%attribs,
             parent     => $parent,
-            value      => encode( $self->{encoding}, $value ),
+            value      => $value,
             type       => $type,
         );
 
@@ -412,6 +418,7 @@ credential based authenditcation
   } else {
       # There was some sort of error
       print $soap_client->error() . "\n";
+      print "Status: " . $soap_client->status();
   }
 
 This method actually calls the web service, it takes a method name
@@ -438,6 +445,12 @@ supplied couldn't be read, the XML you supplied was not correctly formatted (XML
 could not parse it), there was a transport error with the web service or Fault/faultstring
 was found in the XML returned.
 
+=head2 status()
+
+  $soap_client->status();
+  
+This is set to the http status after fetch has been called
+
 =head2 results();
 
   my $results = $soap_client->results();
@@ -507,14 +520,11 @@ to one of the other ones and see if that helps.
 
 Encoding defaults to UTF-8, but can be overidden by the 'encoding' argument
 to the constructor. The encoding setting is used to flag the SOAP message
-(e.g. C<<?xml version="1.0" encoding="utf-8"?>>), and to encode and decode
-the sent and received data between the chosen character encoding and internal
-Perl string format.
+(e.g. C<<?xml version="1.0" encoding="utf-8"?>>), and to decode the received
+data between the chosen character encoding and internal Perl string format.
 
-Field values and attribute values are encoded (using C<Encode::encode>) to
-the chosen character encoding during the SOAP message creation, and the
-entire returned string is decoded (using C<Encode::decode>) from the chosen
-character encoding once received.
+Field values and attribute values are no longer encoded (as in v2.2), since
+this now appears to be handled correctly by C<XML::LibXML> and C<SOAP::Lite>.
 
 Note that this currently expects that the returned message will be in the
 same character encoding - it does not parse the response for an 'encoding'
@@ -538,13 +548,6 @@ Leo Lapworth <LLAP@cuckoo.org>
 
 http://github.com/ranguard/soap-xml-client
 
-=head1 COPYRIGHT
-
-(c) 2005 Leo Lapworth
-
-This library is free software, you can use it under the same 
-terms as perl itself.
-
 =head1 THANKS
 
 Thanks to Foxtons for letting me develope this on their time and
